@@ -2,14 +2,14 @@
 
 Copyright (c) 2020 Ayoub Malek and Vanessa Sochat
 
-This source code is licensed under the terms of the MIT license.  
+This source code is licensed under the terms of the MIT license.
 For a copy, see <https://opensource.org/licenses/MIT>.
 
 """
 
-__version__ = "0.0.13"
+__version__ = "0.0.17"
 AUTHOR = "Ayoub Malek, Vanessa Sochat"
-AUTHOR_EMAIL = "vsochat@stanford.edu"
+AUTHOR_EMAIL = "superkogito@gmail.com, vsochat@stanford.edu"
 NAME = "urlchecker"
 PACKAGE_URL = "http://www.github.com/urlstechie/urlchecker-python"
 KEYWORDS = "urls, static checking, checking, validation"
